@@ -25,7 +25,7 @@ def crack_datadome(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[Session] = None, cookies: Dict[str, str] = {}, proxy: Optional[str] = None,
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
 ) -> Tuple[Session, Response, Dict[str, Any]]:    
@@ -38,7 +38,7 @@ def crack_datadome(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             session.update_ipinfo()
@@ -256,7 +256,7 @@ async def async_crack_datadome(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[AsyncSession] = None, cookies: Dict[str, str] = {}, proxy: Optional[str] = None,
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
 ) -> Tuple[AsyncSession, Response, Dict[str, Any]]:    
@@ -269,7 +269,7 @@ async def async_crack_datadome(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             await session.update_ipinfo()
@@ -412,9 +412,9 @@ async def async_crack_datadome(
         
         if parse_index:
             if interstitial:
-                parse_index(extra["html"])
+                parse_index(extra)
             else:
-                parse_index(resp, extra)
+                await parse_index(resp, extra)
         
         for verifier in verifiers:
             
