@@ -1,7 +1,6 @@
+# -*- coding: UTF-8 -*-
 
 import sys
-import warnings
-warnings.filterwarnings('ignore')
 
 from typing import Optional, Literal, Union, Tuple, Dict, List, Any
 
@@ -82,7 +81,7 @@ async def async_crack_perimeterx(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[AsyncSession] = None, cookies: Dict[str, str] = {}, proxy: Optional[str] = None,
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
 ) -> Tuple[AsyncSession, Response, Dict[str, str]]:   
@@ -95,7 +94,7 @@ async def async_crack_perimeterx(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             await session.update_ipinfo()
@@ -189,7 +188,7 @@ async def async_crack_perimeterx(
                 raise Warning(f'验证失败, id: {nocaptcha_resp["id"]}, err: {nocaptcha_resp["msg"]}')
 
         if parse_index:
-            parse_index(resp, extra)
+            await parse_index(resp, extra)
         
         for verifier in verifiers:            
             resp = await verifier(session, extra)
@@ -197,7 +196,10 @@ async def async_crack_perimeterx(
             retry_times = 0
             while resp.status_code == 403 and retry_times < max_retry_times:
                 did = extra.get("did")
-                
+                _branch = extra.get("branch")
+                if _branch:
+                    branch = _branch
+                    
                 captcha_args = {}
                 try:
                     captcha_args["captcha"] = await resp.async_json()
@@ -240,9 +242,9 @@ def crack_perimeterx(
     user_token: str, href: str, app_id: str, 
     parse_index: Optional[callable] = None, verifiers: List[callable] = [], max_retry_times: int = 2,
     internal_host: bool = True, branch: Optional[str] = None,
-    developer_id: Optional[str] = None, 
-    session: Optional[Session] = None, cookies: Dict[str, str] = {}, proxy: Optional[str] = None,
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    developer_id: Optional[str] = None, auth: bool = False,
+    session: Optional[AsyncSession] = None, cookies: Dict[str, str] = {}, proxy: Optional[str] = None,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
 ) -> Tuple[Session, Response, Dict[str, str]]:   
@@ -255,7 +257,7 @@ def crack_perimeterx(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             session.update_ipinfo()
@@ -296,6 +298,7 @@ def crack_perimeterx(
                 'user-token': user_token,
                 **({ "Developer-Id": developer_id } if developer_id else {})
             }, json={
+                'is_auth': auth,
                 "branch": branch,
                 "href": href,
                 "app_id": app_id,
@@ -326,6 +329,7 @@ def crack_perimeterx(
                 'user-token': user_token,
                 **({ "Developer-Id": developer_id } if developer_id else {})
             }, json={
+                'is_auth': auth,
                 "branch": branch,
                 "href": href,
                 "app_id": app_id,
@@ -353,7 +357,10 @@ def crack_perimeterx(
         retry_times = 0
         while resp.status_code == 403 and retry_times < max_retry_times:
             did = extra.get("did")
-            
+            _branch = extra.get("branch")
+            if _branch:
+                branch = _branch
+                    
             captcha_args = {}
             try:
                 captcha_args["captcha"] = resp.json()
@@ -365,6 +372,7 @@ def crack_perimeterx(
                     'user-token': user_token,
                     **({ "Developer-Id": developer_id } if developer_id else {})
                 }, json={
+                    'is_auth': auth,
                     "branch": branch,
                     "href": href,
                     "app_id": app_id,
@@ -388,4 +396,3 @@ def crack_perimeterx(
             retry_times += 1
 
     return session, resp, extra
-
