@@ -1,7 +1,6 @@
+# -*- coding: UTF-8 -*-
 
 import sys
-import warnings
-warnings.filterwarnings('ignore')
 
 from typing import Optional, Literal, Union, Tuple, Dict, List, Any
 
@@ -15,6 +14,7 @@ import json
 from loguru import logger
 from curl_cffi import requests
 
+from ..magneto.response import Response
 from ..magneto.session import Session, AsyncSession
 
 
@@ -25,7 +25,7 @@ def crack_shape_v1(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[Session] = None, cookies: Dict[str, str] = {},
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
 ) -> Tuple[Session, Dict[str, str], Dict[str, Any]]:   
@@ -38,7 +38,7 @@ def crack_shape_v1(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             session.update_ipinfo()
@@ -66,8 +66,6 @@ def crack_shape_v1(
             script_url = site_arg.get("script_url")
             vmp_url = site_arg.get("vmp_url")
             vmp_regexp = site_arg.get("vmp_regexp")
-            if not request:
-                request = site_arg.get("request")
     
     origin = "/".join(href.split("/")[0:3])
 
@@ -189,7 +187,7 @@ async def async_crack_shape_v1(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[AsyncSession] = None, cookies: Dict[str, str] = {},
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
 ) -> Tuple[AsyncSession, Dict[str, str], Dict[str, Any]]:    
@@ -202,7 +200,7 @@ async def async_crack_shape_v1(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             await session.update_ipinfo()
@@ -231,8 +229,6 @@ async def async_crack_shape_v1(
                 script_url = site_arg.get("script_url")
                 vmp_url = site_arg.get("vmp_url")
                 vmp_regexp = site_arg.get("vmp_regexp")
-                if not request:
-                    request = site_arg.get("request")
         
         origin = "/".join(href.split("/")[0:3])
 
@@ -354,10 +350,10 @@ def crack_shape_v2(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[Session] = None, cookies: Dict[str, str] = {},
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
-) -> Tuple[Session, Dict[str, str], Dict[str, Any]]:   
+) -> Tuple[Session, Union[Dict[str, str], Response], Dict[str, Any]]: 
     if not session:
         session = Session(
             user_agent=user_agent, 
@@ -367,7 +363,7 @@ def crack_shape_v2(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             session.update_ipinfo()
@@ -397,7 +393,8 @@ def crack_shape_v2(
         f"accept-language: {session.client_hints['accept-language']}",
         "priority: u=0, i"
     ]
-    html = session.get(href, headers=headers).text
+    resp = session.get(href, headers=headers)
+    html = resp.text
     
     if pkey:
         if not script_url:
@@ -510,7 +507,7 @@ def crack_shape_v2(
                 }
             ).json()
         else:
-            raise Warning("网站异常或参数错误, 请联系管理员")
+            return session, resp, extra
         
     if debug:
         logger.debug(nocaptcha_resp)
@@ -534,10 +531,10 @@ async def async_crack_shape_v2(
     internal_host: bool = True, branch: Optional[str] = None,
     developer_id: Optional[str] = None, auth: bool = False,
     session: Optional[AsyncSession] = None, cookies: Dict[str, str] = {},
-    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http2_only: bool = False,
+    timeout: int = 15, allow_redirects: bool = True, verify: bool = False, http_version: Optional[Literal["http1", "http2"]] = None,
     user_agent: Union[str, Tuple[int, Literal["windows", "macos"], Literal["chrome", "edge"]]] = None,
     ipinfo: Dict[str, str] = {}, extra: Dict[str, str] = {}, debug: bool = False
-) -> Tuple[AsyncSession, Dict[str, str], Dict[str, Any]]:    
+) -> Tuple[AsyncSession, Union[Dict[str, str], Response], Dict[str, Any]]:    
     if not session:
         session = AsyncSession(
             user_agent=user_agent, 
@@ -547,7 +544,7 @@ async def async_crack_shape_v2(
             timeout=timeout, 
             allow_redirects=allow_redirects, 
             verify=verify, 
-            http2_only=http2_only
+            http_version=http_version
         )
         if not ipinfo:
             await session.update_ipinfo()
@@ -689,7 +686,7 @@ async def async_crack_shape_v2(
                     }
                 )).json()
             else:
-                raise Warning("网站异常或参数错误, 请联系管理员")
+                return session, resp, extra
         
         if debug:
             logger.debug(nocaptcha_resp)
